"""
Various constant values

KST 20140903
"""

import os
from pathlib import Path

# path information of the package
__ROOT = Path(os.path.dirname(__file__))
PYMRIO_PATH = {
    "test_mrio": Path(__ROOT / "../mrio_models/test_mrio").absolute(),
    "test_mrio_data": Path(__ROOT / "../mrio_models/test_mrio/mrio_data").absolute(),
    "testmrio": Path(__ROOT / "../mrio_models/test_mrio").absolute(),
    "test": Path(__ROOT / "../mrio_models/test_mrio").absolute(),
    # TODO remove "exio2": just here to keep the tests running
    "exio2": Path(__ROOT / "../mrio_models/exio2_pxp").absolute(),
    "exio2_pxp": Path(__ROOT / "../mrio_models/exio2_pxp").absolute(),
    "exio2_ixi": Path(__ROOT / "../mrio_models/exio2_ixi").absolute(),
    "exio3_pxp": Path(__ROOT / "../mrio_models/exio3_pxp").absolute(),
    "exio3_ixi": Path(__ROOT / "../mrio_models/exio3_ixi").absolute(),
}

# generic names (needed for the aggregation  if no names are given)
GENERIC_NAMES = {
    "sector": "sec",
    "region": "reg",
    "iosys": "IOSystem",
    "ext": "Extension",
}

DEFAULT_FILE_NAMES = {
    "filepara": "file_parameters.json",
    "metadata": "metadata.json",
    "download_log": "download_log.json",
}

MISSING_AGG_ENTRY = {
    "region": "Unspecified region",
    "sector": "Unspecified sector",
}

STORAGE_FORMAT = {
    "txt": ["txt", "tsv", "csv"],
    "parquet": ["parquet", "par", "parq"],
    "pickle": ["pickle", "pkl"],
}

# The default column name for the value column for long table format
LONG_VALUE_NAME = "value"


#  Download links for Gloria MRIO files
GLORIA_URLS = {
    "053": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACPnp0qOD1N7CSjv0reFKSba/previous_releases/053/MRIO/GLORIA_MRIOs_53_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACD6UmIBqbmkAQiAOfX7U_fa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD6y_13ul9SZnJkPV1GhZCza/previous_releases/053/MRIO/GLORIA_MRIOs_53_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA5bFH6uzjqhm6fowdMlkyLa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB3PLbnxPHIP2MGN8S36ZUBa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABIfGIVZkelhq58Ij1DKO1Va/previous_releases/053/MRIO/GLORIA_MRIOs_53_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAqOhcAo8jFU_GhTu1fzOKWa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABspySp6y4Jh2OaLrTlSeY_a/previous_releases/053/MRIO/GLORIA_MRIOs_53_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABAXczzTGbWj8i-ho0fSTsLa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABK94uXvjIdWzrgCP5uxk6Wa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABTfP3rpj_QkIPyPIJqVo62a/previous_releases/053/MRIO/GLORIA_MRIOs_53_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABW9BpSx6h83gpmyCnVfKZ-a/previous_releases/053/MRIO/GLORIA_MRIOs_53_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADvhpsqMor0wvNFLD-zWcRAa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADS3ffwpUxjkoLlQneJrrUDa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABdMfXMCF6b3HqTJEjyQkTsa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfHBfF-5N0ZaYr-gwfJKSya/previous_releases/053/MRIO/GLORIA_MRIOs_53_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADWa9MT3qH_YAVwlqb2-eEBa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABT4WkwUQt_5KbPsWMgUUFba/previous_releases/053/MRIO/GLORIA_MRIOs_53_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABfxaEEsKc8MKndscJMxilha/previous_releases/053/MRIO/GLORIA_MRIOs_53_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB7j7bikNb1q3RhTyyLB9mQa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABrkCHIOdLU5zUmHuI8nDKma/previous_releases/053/MRIO/GLORIA_MRIOs_53_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAW_BEqaeIvAzmFE6oYz8rKa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB2ktuivgPwclQXVNQbh_Afa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyg36facQvwueC6r85yEY8a/previous_releases/053/MRIO/GLORIA_MRIOs_53_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA7Z0xEExKNK91GvinGGk9va/previous_releases/053/MRIO/GLORIA_MRIOs_53_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD1rYcXCwCvNxC4wV8apUFCa/previous_releases/053/MRIO/GLORIA_MRIOs_53_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD-J1n98SSYniRLSNfEe0kJa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAQc9jieTHGraE9nRGha1g4a/previous_releases/053/MRIO/GLORIA_MRIOs_53_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAzRQsWiNc6Wu_5mOXAV1YIa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADPrsw4iWytQ9ItCpJ8ZqwIa/previous_releases/053/MRIO/GLORIA_MRIOs_53_2017.zip?dl=0",
    ],
    "054": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC7K5dfdnOA3I_CJm4Bu0nHa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACO5ce_FtnXN-w8ZykcqrCYa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACvnqqeofEQPAG0X-BWxNRta/previous_releases/054/MRIO/GLORIA_MRIOs_54_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABXuHtPoMajYNR5YH18Frf_a/previous_releases/054/MRIO/GLORIA_MRIOs_54_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACOfDR7Jtk83cEzFQwktbGja/previous_releases/054/MRIO/GLORIA_MRIOs_54_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACmf_zQswJz60ZWzorQ6Bpua/previous_releases/054/MRIO/GLORIA_MRIOs_54_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADXNVDIgSjiTq2XYZBOp3TXa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABpxrh-7mFDL6va4d6Z3E_za/previous_releases/054/MRIO/GLORIA_MRIOs_54_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACwD1DOvsiLNxsMreU3Vo3ua/previous_releases/054/MRIO/GLORIA_MRIOs_54_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABlYAdTmli3iDfM3li2OAxxa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB-HUu421eE7VkH0yQV6KwAa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACqNzqTjYXrR6cJ7fpp2-_ua/previous_releases/054/MRIO/GLORIA_MRIOs_54_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABPAFDyayr8LUfTr1R8F6DAa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB1In5emdB928-a0B1j_Uo0a/previous_releases/054/MRIO/GLORIA_MRIOs_54_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABHnhwWKGOYcSMyXFxCS7Dfa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADZ2etvFvgEUOoCWRHgfUcNa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB5bz-aVrQVkj5ZSuAuGhuAa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACHEcV9TmcUUIXxd2trwzj0a/previous_releases/054/MRIO/GLORIA_MRIOs_54_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAADEQMUbcrbfItvHEgs9Tqxa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAAC8oUPc0Bf_xpiS-vMeWNa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACiG4RqHNhtOTvNkqPGvFEsa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA7I_SrhI8gklR7Za2drsNFa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACmGlhuY9zeijQCdllbwkdpa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD8snAscs6LFBF4mRlo7qsfa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACr37Rp_r7nbxaUgv8TzvlHa/previous_releases/054/MRIO/GLORIA_MRIOs_54_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAujo-1iMVSz7N3ozLLN3Zga/previous_releases/054/MRIO/GLORIA_MRIOs_54_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAt3nE7WeWQxzkeVtabsm4Sa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABFO3rlAXAI9MuZfd-KQ-9ia/previous_releases/054/MRIO/GLORIA_MRIOs_54_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB4j8NBysXu4MkgvZYmrSwfa/previous_releases/054/MRIO/GLORIA_MRIOs_54_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC-XyiKcDOn9TYmeDPKjyfna/previous_releases/054/MRIO/GLORIA_MRIOs_54_2007.zip?dl=0",
    ],
    "055": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACmYOJiT8mK1uHLQlCgn4Oya/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD11mTRGEtcqf1dRMFtQrYza/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAljBvDe2kgEL7AjDOPfF5Ca/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACdxKvPfZo8JzkQIJxbo3rxa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFPwnkn4sWCdzmxXTXNLJKa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABnBRFa0IY4iS8yU3U3bQ-ca/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC1Ms5inScRNGD_UtqRZ4cba/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABzqn-iNshbGn3PV2rDgOEma/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfXq94cK9HgqDGRw0Av51Ra/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABPCBRPcNkDgIKV0f4Aoh-aa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABeYfN4oPwiHGMVvrdM2H7ia/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABbWD78TEiNbnZs5pZkMNSaa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADwlWrpZShpxWm0frKPU3Aja/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFSmp0PcO7UeRmC8xokRwea/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAc6MD3-u6nvoPgg3cL9tvoa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC2cg37BrUzSg3pQg3CxnLDa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACF6A0mQQ9UwvsBKCU05z0va/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAATYbJBOR6XHN6H4QRAC6tFa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAJ-gud5eL1kgvJvXAT-3zja/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA5EQmc0cDiVe6KfOsnZXesa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACTtJbqQWeSNVe1Z0jYJ_rra/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADttP2Z4KGdU4mnd58f0w2Sa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADS7y82yMnifEnpPHPuoxITa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACSkVqnHjhc1k9NY_3uDgJFa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADxMiz9payAd6cpgxoUDIw4a/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC9BjOyOaaSENX_DfMcIU-qa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD3y0caXYJPtvvZezhXEQUUa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAF9FaRBH7Hk1r48GYcilfGa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACyvsy2YPCAFqBgHC2YZWaba/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADSHS7zJ05U5Zm4FUtrldpRa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA_hJiYUEo8gVZbqp7HCgMPa/previous_releases/055/GLORIA_MRIO_Loop055_part_I_MRIOdatabase/GLORIA_MRIOs_55_2020.zip?dl=0",
    ],
    "057": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA6XcwTY5cPBHfE7FDg9ekSa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAEU1NHMpIRHtbMTJGzX-hya/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD5JjkTWAs84_-CarcY0sf-a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACvyY2AWTm5E6g33GTjuUX3a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC0kZH3hMJzFD0zOSV-hXqYa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB2T0crYxuweitpotYGgql5a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB1pCSAiRrNdLocI-utrzUQa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC3dPPybkq_4hjJnDO_0LANa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAacUC2yoruzbtfCu7S7lc_a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACjI39Ah1YsvN6ybdTWoOtGa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAax8DaONief8spCaFSPhHBa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfv2dQN-j2Er0Ki7EEJG7Za/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABgP-Vc2CYHZDHEgXIe9TLfa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABOEQygV5SNhbtURn5qhirsa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACpcnLaFa1PVeJhS7sPiJD4a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAZko6iV75_8T8s-5W4fsnHa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABnx3q63E2awnzGPZEXz4dZa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAvxvKCIYr3GnBgQx-wmrWda/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADltNbHhQbVFiu8gs2m2bL5a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABYaJUomI88jntKgiIDmvAYa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAALWip1Lqi_HGlzMgcOaGRGa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAAc1pEMM9q306ERP8UzrVia/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD5iMVB7im7drGO_FaE6Nr6a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACLbEdxbIFpJbXgtycjs6tIa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC2HunFEPQMtgMVXR4Jwg2ea/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABIX8KqWfAiVMpUlt2Nz2hqa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABI6JADz72WnzbA58-SAf_ja/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACOHJyTKwE3PWkxRd4B9Nmqa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADgJrD36TjnbBWmLZXxC8u_a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC1LkXZXFL8wy0BZTu3YU_ma/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABZDIIyPZIEYtbrqNlegtL4a/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABFNKBuvtUG1UAOyQCG2Lxna/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADi2bZiNI6MRi825OwfsR7ea/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADHNM6TLsYY7indEpkFd7FOa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA4eTO9UoUdBWKT0oe0oRcMa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFYVV1HW0wLhGoFcjmCEkPa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADeVxiyJwJS6kJhfafnHSqTa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACWuruYd7h2x3YDJBz281soa/previous_releases/057/GLORIA_MRIO_Loop057_part_I_MRIOdatabase/GLORIA_MRIOs_57_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACLs5vplfc10hSS1KENlpmca/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACqlo7EDAc3FSrxALPG4DHZa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx7F9gH87Dc6LDPzf3fcTya/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABDSFS4prMK_4mRgbvikoPHa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx-PVv5sC-EFjhUwiqjxg5a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAOlf5PPkxIlJtjRjdndh56a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABjSmFGcB94WqnUfC0NxfIja/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8O7HuVYMgqv7pxkqimsWRa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAqXP-avzvdd15VGUoEE84ma/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACw7DFT-ocxhjsH6RyoiWNka/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABh5ctBTx-JF_h7iCP6GyUUa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABF3xC3yphEq2bxphygkB8ka/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACwp-KzY3Mro5XRHqmhWgHWa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD5UwUUT3vdDc0yhjpkejkBa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAdJRkNO76p5RR3b83XaI-Ua/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACjKEAKrIi9cx0In_8hDKSba/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABm_O4Wmqn3cbPq8HhdBcXOa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADBd996bMTdUYJYIT5--kYSa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABF6jBVtrWjXAQoqRMsGTGoa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAmN2PJAf1LOL22tPpNEr2Va/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAChcWu19A7qb2nfclQQQTqda/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7p64prYW_KYDEho4I0-qxa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABe87Xzy5DQDyge34VQlGs2a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADTJExBV0XtMQtP2hC6j5S_a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADMRtFKFzt7Mh4YB-4DVMDza/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACDRHQP9X1k-UAOjY5ymX_qa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABSay731cFtpDVVuzmGhHOea/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABdYrSjF9uxt_qvLX4ot1Eva/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAdIS4iY9GiuyS8sOmGG3EZa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8Q84V-OCsaqmFEOUw7d7Ua/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAPBHeohNkCngHYIy72EGIEa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAfkUgvpXCah6kB_39G57CGa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7lHRnfjpZ70E459aaGA7wa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADHdG-CyCm057Wuh0ZS1oTVa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADc5FEJ86TOlZirJA1ao0_ka/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADe_F-Swg5_BbBecGsFmWt8a/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAByiBs3VtV9louQf2EtYaFsa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABPn1_2mNrwOQOPHTO54XbJa/previous_releases/057/GLORIA_MRIO_Loop057_part_III_satelliteaccounts_Aug2023update/GLORIA_SatelliteAccounts_057_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACVMxOQl_p1i4jA4vSzcf_Va/previous_releases/057/GLORIA_ReadMe_057.xlsx?dl=0",
    ],
    "059": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABYYsdfwd4t0sgt6UQKGW8Ya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADnynCU-aKsMX9kk6n0tUvTa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7c-bfG4N0qt5BKOnjIM3La/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABsyp2R_ct1yu_hODaFDtOaa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADUH7KmNh8gCdK2ZVUfBK9ka/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABqFE_P6YAkkuQszzIZISn0a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACHdzbRnvx1laL0dNQkp1T6a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADfR5w1bN2ZixOo1hmuVXyea/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC71K3VxYBwrMrXmsdhc0A9a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB-wTaCjSuldHo0PNfI8cHfa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACwZP1tlf2Qb8U_D_H4xQUja/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACuVV3GaYexY-vYg-omW1mya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABKuG0A7TAolAL4rNQ4QLqja/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACTH-ud2dw8ldKiVAofv8AXa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADwR5isYDbjRVLAyp1PVI5ga/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAeb2Dwu51KHWlXjee34HpUa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAANcXP3JJpDCtQlPjT2B_Pya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB5t5MNOWKHEsGUmmxs6H7Na/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACZV-0TWU3sEIY5GjNdwC4Ua/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABUvrUozc1xwvLsQh9y_JDpa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC4KGu1X4rPwmUsoBmqv6PAa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACkzjMP5FnbGusvix0MA15qa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7otFAX0-41_jaIhy_ZczFa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAoZCRgkzeBoduOHptss2cha/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8VkCE7rpnHNqSS6R-Bw3xa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAADgEbJVwrVcOrPXsSWxbLKa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACAxqOI-H6I6bFHZWJ2YCMwa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA69qMZDCahQcgmPNCThSBwa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADYDClolKFUsSE1Y6o6ftyJa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAbqfOTmMlr2gp7c_PBvkOja/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAbXjQvMJ5e1EbMq1g-iP73a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD8QVqW1wQWpHbX6GAVyqNea/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAACbZOBtu8OC5ashBa5f_kba/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyEnDJTr6yVsAaY5tkC4E2a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA65q1b0ikO9GMWQI5k5U7la/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAmo9y0blTG77_PK3dC_tYya/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACOld8AXWJrJcb31-UokhrHa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADYt7OKTqQDRwSer-TeDJlKa/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABB8f1we-FhAQXpMe5mxWG7a/latest_release/059/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx92sK9wI4DHLc9-yYtHufa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADjaG75JFlxCDbckU4SieRaa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADB_tZsfwsEiZRKOd03dV6ia/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACIXtkLlDmW5R-ZjGvYi57Qa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADH7RtSusEOslpe7kyIhsvEa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACKWSmKYViXTLYBpG6Jf1Ffa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADj98e6-qWZs-t-8Dke1ZiKa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyJX_CCq6Jt17m0Rney_cHa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA_OGQqIhWIy93mQ8ARN9jXa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAkvoLbRqu0WMTtRZwrEILRa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA0mFolJm0dxJ4GFTc4mN13a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADq998BYk9J1CzOjtFwGqOZa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABMn33RAmbolGXq2Pb9b4Wka/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADKKNiln5HjNQB8IB6kUTKta/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADuVIM89hBj5RF1eeu2B07qa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADgkb8iSE3ndGw0VO9ijSWaa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACyMSQqYORqs2J8tgdVWRw_a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACEYZqic1WtOWphIOgFoBQZa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABpLIzmzKSGnmDawNfEiMJra/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA6ZwAZd2YGTDODz3X8BQY3a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD7p2twdLVBn7_Ma6f_T5O8a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADh_VCk5P1l-mXWLJ6yCT0Xa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAClhxk2FW3coyYNrKCH5T7ha/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAEIZeHCQ_IBQqFTiJ5HZkya/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABfegadZLtayvxFvCJF7SR7a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC4YFJzlmqlmEyJ_dJMXpeFa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABhPhw9R3eweXFabbVrG5nAa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADctOuMcGUp5yW46XOdql2Ja/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADwR34CAYoOEDUCuGWa0jfHa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAKnTf2eSXyhmWjxwzMyAewa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACuy8sqT-jDaVuw6eiYkdIDa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC8I3418CZ7HXVsHpjU2TTea/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADIJV3Af0quGGV2hsnOc-U8a/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACud6Xt3vPEyIkzEAu4CYbAa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACGy9iQIpsn9gigppfX7GZla/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACJ814P9-jR3SmTWdnOTVmAa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC-vQpAqKoxT3dFTcxgwAKJa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABagKTX5hXyqk2Rgor9S0jba/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAGVEWD6RLTSMDgaQjqeqZKa/latest_release/059/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABw5dyUYvEAWbG8n9-yXAPqa/latest_release/GLORIA_ReadMe_059.xlsx?dl=0",
    ],
    "059a": [
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACC_m_D32e_XUclwARi19g7a/latest_release/059a/GLORIA_MRIO_Loop059_part_IV_commodityprices.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACZlIzKDAi29CzU792I_nYRa/latest_release/059a/GLORIA_MRIO_Loop059_part_IX_datasourceintercomparison.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADxD5b95lLfPk6wRVzhI402a/latest_release/059a/GLORIA_MRIO_Loop059_part_V_footprinttrends.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADyAoZhZ8Xl2YsjOOZU7bhPa/latest_release/059a/GLORIA_MRIO_Loop059_part_VI_Diagnostics.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAZuY3C4qbPysaGRMFEnCy7a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABIg72BYQFmYQxBGAAeCm2Na/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADKTkkUNbdm97c38IrDRB8Ca/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADCkyxJKrOkPZ3fjwrcmU-Ua/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB5J8qmGICClI4WQlvpa3jaa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAgw1YO3mkFdbBZUn572ETKa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAAm3ehiXI3owONVde9eGxda/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC5vcUu2MKAu1xODSy9YRgea/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADfhrQAwCx-Ofi_cMKxz1l_a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAASfo0SxpUkE1mAEWwe3Lyaa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABImpkuGeUs2UyX1K9AFcVJa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADtBmrTwrLnjljr-uWkbIcAa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABrYYR4pDGUr7jdKQtVaM7Za/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA1bUtqsrv5XcRjI36PcIOYa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC009lzhGLbkVxf6HkyHfl3a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADu4VUfjsnnRA6-3rAbtjYJa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABSWsYcORL_M_HXV_o-6lTfa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC23_DGq9w5MpjoGuWtBJQ6a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD_o_SGwU8oF5QhxlpTyZwNa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABcHpg7E-De9cgqnbsSI4V1a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACeN8I7Q1wUR4gvA0CTYpNWa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADM4PntKaJLN3bzO1Ez6pNka/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACZfF_uHSlBe7qZxurlV1kka/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADsRWheT2tZaYbilQ-zWfCUa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFqhH-yQoQKzhARvDzv2fua/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAk6_-OGISSnyzVqZkU4ncHa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABld6xF0Vx8laejZxo85uNJa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD6RpUY_4ph-ee0TIe4ypAsa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB2aK_ut48RZQRjcc_qTQoKa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABYllMh9jBrdUprBdEIkgXSa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAByzV2RBWZI_wKiDiVDKVpia/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAiHM6jqNDhB3HA36Cc92QEa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABj-GFI6AEc6arTUkR5Gvb3a/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACSI4hoS_QEsxYc0MGm7SAoa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABcbIaWUMeGjCyC-OaRoUzAa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABv8rlwnmXO8Ko3odzLfluHa/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACkDV1EcXSRu-Is8owA353na/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADk2bGu84P8j997elHdA0-ta/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD-R6NueTusZ_SJL-4ElU8Ta/latest_release/059a/GLORIA_MRIO_Loop059_part_I_MRIOdatabase/GLORIA_MRIOs_59_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACCBBzZX9pQ7rbD4hUV19HGa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABm3ZXfajKK6DMuzKpaQVsoa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADcv0zcCYyEcPoieqaHDj7ha/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAodGVLiGA6DLk_4SkrTR_da/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACpAjOOqidjnjvF-kbbR5Nua/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADQV9hpK1f_ZKTPGtskxCQga/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB7SkDSiorEhtdysH97lPbqa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABNWNZppaR8jPUC4ThOvn4ua/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACp-2HVGqW3I4-KzbDoaEBPa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABn7FF1GYWMcHudTrCU9UBZa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACPH2jDeYRlegcO_V-b8z0fa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAUDrB21dzvvqOvkkVeF5ZJa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACRzhq5aNgIBwkaCGA7IjwQa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADzWmevcioBPKyIXLFeo1z5a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACq2wDe6RctazXI4vXtmkBia/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB-nzy3HHKP16krr_ETAyMwa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABLWVkhl2OmE8nFjzhl5no1a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAQh-UlDHC8RNK8ihjIxLtha/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAwtwL1DEjrHgrAwelG2zdva/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD_X5dXAqqjxVt2ptR5T51Wa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAuaXZ3uYHbXYvI6_HFxQOHa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAJ2c_aPmR1zsehnyfp2JtBa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACzSqFH-mTqouDM4YUiszbqa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADa6iKQuNluwhSBmDtFdOaWa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAi-Z7OvotiZylyCTL75fNea/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACh20dPllzJDR2DYm31q9w3a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA4BrI28S7swRyTGdRz278Na/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC4IaWAfTggUNpU0mUJiQLAa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAMe5w8IlsI7SNfOWaJKlv2a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA5HXW36Ki0WqpBdnmxCGXXa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAh7URYNcgBAJvlZdMiTs7ca/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADx5cnuvvEQIttkRApTlNhla/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACMumxcsLjGgrNV4dtvI445a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABuMvb1onuwFj6049fvlvyWa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABwfza6j6BtHD3qSjSdfEr5a/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACrChYEp68kffU3iUKIP19ua/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADY-qxXpIeyML2LNxP5P17ta/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADoCYLhwW_XZzhUyHaO5_Xda/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAArmAZ401qackDhz-3eqBXOa/latest_release/059a/GLORIA_MRIO_Loop059_part_III_satelliteaccounts/GLORIA_SatelliteAccounts_059_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACoPtVa7FM3jbUNOW-CCWt4a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1990.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAbCQ4lrX7XdELz8yKq7hgga/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1991.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADy9bgiPkVHKju40KWAqp7ea/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1992.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACe7k4X13o1FhdrR9bGDkzva/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1993.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACRuG5UmMm7jQAgpkoNWinUa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1994.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAG3cq_s1ovV4r2PpdT4CJTa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1995.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAcAqczBCyX1-Gb2jGx6LJia/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1996.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADP6IUspF03_-ScrqxWGOYca/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1997.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABbYE-_7BzSw-nyAaof4Gqwa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1998.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAQKOtnXMn5RBkJg_Z7fU7la/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_1999.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAACzsyOd-FAMsbR08BHSP3Ma/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2000.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABoGJAdadDU0l1QSYX90INDa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2001.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADiaBTC4u5vhFD97lFctT5Ya/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2002.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABK_1Lg2n4joR7bJG0ku8cza/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2003.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC2mFvRl_bTJW7ILLx7VJaea/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2004.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACC1HRarAQu92dqXVsZ1eZra/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2005.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABWEueWQotoT9D6wv2rUdw_a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2006.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA0OgFD61kZPCYQm-jzTelQa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2007.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABSVI8rowLH_dVlQaEdh0HOa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2008.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADuQe7pvRK2XOuGvdLETALca/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2009.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB84ILtm8pBZYU9gjzPqDO3a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2010.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACy7fHMKoxUg-GY54-Ph3RBa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2011.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADbtJhGsj9-0PXx4OoOessDa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2012.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAASFzbOYKYJqRzLJGg4tFA3a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2013.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADJxbyn485Zkac9gCqVwko4a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2014.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAA6NYtvGIQtcd9Ds5OZFX3va/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2015.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAD_3co6LC7NdoXS49z6EuqIa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2016.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADMiTDO1lxcRpdWZD3AUsG3a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2017.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAAO7YCQwaTK3Z7Il9IkSBKka/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2018.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADfiZsOpQPJwDptRAL9WJEHa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2019.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABQdtWCzpF-df1TEBUIvzRMa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2020.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADTHd-Czn9d8Kths6A33_f5a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2021.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAB_LOozNk-NdSC_YnAp6ROXa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2022.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACcdymoASi-070OwJ75yZmza/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2023.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACrp7OZGj53sBmz9e3xacI0a/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2024.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AADa3ZTaZiVK3O4_D57QUwrBa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2025.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAC0NjjWRQsTZg7NVCmXV7Spa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2026.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AAACjEG5KLnCpJAL1Ce5-kkca/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2027.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AACFQmRuxxaE-4qw3UWcU4uLa/latest_release/059a/GLORIA_MRIO_Loop059_part_II_standarddeviations/GLORIA_STDDEV_059_2028.zip?dl=0",
        "https://dl.dropboxusercontent.com/sh/o4fxq94n7grvdbk/AABmWnrDE-nhbKokOv-hYOXEa/latest_release/GLORIA_ReadMe_059a.xlsx?dl=0",
    ],
}
